<div
  id="chartwerk_{{id}}"
  class="chartwerk"
  data-id="{{id}}"
  data-dimensions="{{dimensions|safe}}"
  data-size="{{size}}"
  data-src="{{chart_path}}"
></div>
<script src="{{embed_script}}"></script>
