<div class="header">
    <h1>
        <a href="{%url 'chartwerk_home'%}">ChartWerk</a>
        <span class="header-nav">
            <a href="{%url 'chartwerk_start'%}">Start</a>
            <a href="{%url 'chartwerk_browse'%}">Browse</a>
            <a href="{%url 'chartwerk_mywerk'%}">MyWerk</a>
        </span>
    </h1>
</div>
