# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-06-01 18:02
from __future__ import unicode_literals

import chartwerk.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('chartwerk', '0002_loadfreetemplates'),
    ]

    operations = [
        migrations.AlterField(
            model_name='template',
            name='icon',
            field=models.ImageField(blank=True, null=True, upload_to=chartwerk.models.template_icon_upload_path),
        ),
    ]
