# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-24 02:30
from __future__ import unicode_literals

import chartwerk.models
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Chart',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(blank=True, max_length=250, null=True, unique=True)),
                ('title', models.CharField(max_length=240)),
                ('data', django.contrib.postgres.fields.jsonb.JSONField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('author', models.CharField(blank=True, max_length=250, null=True)),
                ('creator', models.CharField(blank=True, max_length=250, null=True)),
                ('embed_data', django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FinderQuestion',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('question', models.CharField(max_length=250)),
                ('order', models.PositiveSmallIntegerField(unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='Template',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(blank=True, max_length=250, null=True, unique=True)),
                ('title', models.CharField(max_length=240)),
                ('data', django.contrib.postgres.fields.jsonb.JSONField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('author', models.CharField(blank=True, max_length=250, null=True)),
                ('creator', models.CharField(blank=True, max_length=250, null=True)),
                ('icon', models.ImageField(blank=True, null=True)),
                ('description', models.TextField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TemplateProperty',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=250, unique=True)),
                ('property', models.CharField(max_length=250, unique=True)),
                ('finder', models.ManyToManyField(blank=True, related_name='template_properties', to='chartwerk.FinderQuestion')),
                ('template', models.ManyToManyField(related_name='template_properties', to='chartwerk.Template')),
            ],
            options={
                'verbose_name_plural': 'Template properties',
            },
        ),
    ]
