@import './colors';

.center{
  max-width: 600px;
  display: block;
  margin: 0 auto 0;
  overflow-x: hidden;
  font-family: 'Open Sans', arial, sans-serif;

  h1 {
    font-family: 'Russo One', sans-serif;
    font-size: 70px;
    text-align: center;
    letter-spacing: 2.0px;
    margin-bottom: 0px;
    color:$flatblack;
  }

  h4{
    display:inline-block;
    padding: 2px 4px;
    background-color: $red;
    color:white;
    font: 12px bold arial, sans-serif;
    margin:0;
  }
}
