$red: #C91507;
$pink: #CC6058;
$blue: #337ab7;
$darkblue: #0066ED;
$yellow: #FCF181;
$black: #2d3035;
$flatblack: #333;
$white: #FFFFFF;
$green: #3cba54;
$orange: #FFA500;
$lightgrey: lightgrey;
$midgrey: #999;
$grey: #666;
$disabledgrey: #aaa;
$shadowgrey: rgba(0,0,0,.1);

$boxshadow: 0 2px 6px rgba(0,0,0,0.14), 1px 3px 6px rgba(0,0,0,0.23);
$boxshadowlight: 0 2px 4px rgba(0,0,0,0.14), 1px 3px 4px rgba(0,0,0,0.18);
$boxshadowthin: 0 2px 4px rgba(0,0,0,0.14), 1px 2px 8px rgba(0,0,0,0.18);
$boxshadowright: -10px 0px 20px rgba(0,0,0,0.14), 1px 6px 6px rgba(0,0,0,0.23);
