.center{max-width:600px;display:block;margin:5% auto 0;overflow-x:hidden}.center h1{font-family:'Russo One', sans-serif;font-size:70px;text-align:center;letter-spacing:2.0px;margin-bottom:-10px;font-weight:bold;margin-left:-60px;color:white;animation:fadein .5s ease-out forwards}.center h2{margin:3px 10px 3px -500px;background-color:#333;color:white;font-family:'Russo One', sans-serif;width:420px;padding:5px;transition:background-color .5s ease, margin-left .5s ease-out}.center a:hover{text-decoration:none}.center a:hover h2{background-color:#C91507}.center a:nth-child(2) h2{width:400px;animation:slideinleft 1s forwards, slidefade .75s ease-in forwards;animation-delay:.5s}.center a:nth-child(3) h2{width:350px;animation:slideinright 1s forwards, slidefade .75s ease-in forwards;animation-delay:.5s}.center a:nth-child(4) h2{width:300px;animation:slideinleft 1s forwards, slidefade .75s ease-in forwards;animation-delay:.5s}@keyframes slideinleft{from{margin-left:-400px}to{margin-left:43px}}@keyframes slideinright{from{margin-left:1200px}to{margin-left:43px}}@keyframes slidefade{0%{color:#333}60%{color:#333}100%{color:white}}@keyframes fadein{0%{color:white}60%{color:white}100%{color:#333}}

/*# sourceMappingURL=styles.css.map */
