<div id="data-preview-modal" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="Data Preview" aria-hidden="true">
  <div class="modal-dialog modal-lg">
    <div class="modal-content">
        <div class="modal-header">
            <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
            <h4 class="modal-title">Make any edits in the paste window or your spreadsheet.</h4>
        </div>
        <div class="modal-body">
        </div>
    </div>
  </div>
</div>
