import React from 'react';
import _ from 'lodash';


export default React.createClass({

  propTypes: {
    actions: React.PropTypes.object,
    data: React.PropTypes.object,
  },

  render() {
      <div>
        <h1>Hello React!</h1>
      </div>
  }
});
